@@ -1,4 +1,16 @@
-pub(crate) mod linked;
+//! # Lists
+//! Library containing various implementations of list-like data-structures such as `Vector`s, `LinkedList`s, and more.
+//! All data-structures follow a sequence-like structure and can be represented like an `Array`.
+//! 
+//! ## Linked Lists
+//! ```rust
+//! pub struct SinglyLinkedList { .. } // One-directional `LinkedList`.
+//! pub struct DoublyLinkedList { .. } // Two-directional `LinkedList`.
+//! ```
+
+
+
+pub mod linked;
 
 
 pub use linked::SinglyLinkedList;
